local agent_helper = require(AGENT_PATH .. "agent_helper")


AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.mg05.youyannet.com/aly/login_verify.php",
	uid = "",
}

--退出
function PlatformAdapter:OpenExitDialog()
	--退出上报
	AgentAdapter:ReportOnExit()
end

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)

	PlatformBinder:JsonBind("call_agent_create_back", function(arg)
		if arg == "false" then
			local format = { title = "初始化失败", message = "游戏初始化失败，请重启游戏", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, 
				function (result)
					if "positive" == result then 
						AdapterToLua:endGame()
						end 
				end)
		end
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "aly"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "aly_" .. self.uid
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/empty_logo.png"
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[22]
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end

	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end


function AgentAdapter:LoginCallback(result)
	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end
		print("verify_callback--", ret_t.user.uid)
		self.uid = ret_t.user.uid
		AgentAdapter:SubmitUid()
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end
	self.is_login_verify_ing = true
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local sign = UtilEx:md5Data(self:GetSpid() .. "" .. now_server_time)
	local real_url = string.format("%s?spid=%s&token=%s&device=%s", self.login_verify_url, self:GetSpid(), result, tostring(PlatformAdapter.GetPhoneUniqueId()))
	print("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
	return false
end

function AgentAdapter:LogoutCallback(result)
	print("AgentAdapter:LogoutCallback")
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter.OnClickRestartGame()
	AgentAdapter:Logout()
	ReStart()
end


function AgentAdapter:Logout()
	self.force_logout = true
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local info = {}
	info.role_id = tostring(role_vo.role_id)
	info.roleName = role_vo.name
	info.level = tostring(role_vo.level)
	agent_helper:Logout(cjson.encode(info))
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end

	local data = {}
	data.itemName = "元宝"
	data.itemId = "1"
	data.amount = amount * 100
	data.count = amount * 10
	data.callBackInfo = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
	agent_helper:Pay(cjson.encode(data), callback)
end

-- 上报UID
function AgentAdapter:SubmitUid()
	PlatformBinder:JsonCall("call_agent_submit_uid", self.uid)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local info = {}
	info.uid = self.uid
	info.role_id = tostring(role_id)
	info.roleName = role_name
	info.level = tostring(role_level)
	info.serverId = tostring(zone_id)
	info.server_name = zone_name
	agent_helper:SubmitExtendData(cjson.encode(info))
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local info = {}
	info.role_id = role_vo.role_id
	info.role_level = role_vo.level
	info.role_name = role_vo.name
	PlatformBinder:JsonCall("call_agent_on_create_role", cjson.encode(info))
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	local info = {}
	info.role_id = tostring(role_id)
	info.role_name = role_name
	info.role_level = tostring(role_level)
	PlatformBinder:JsonCall("call_agent_on_role_lev_up", cjson.encode(info))
end

--  退出上报
function AgentAdapter:ReportOnExit()
	if GameVoManager and GameVoManager.Instance then
		local role_vo = GameVoManager.Instance:GetMainRoleVo()	
		if role_vo then
			local info = {}
			info.role_id = tostring(role_vo.role_id)
			info.roleName = role_vo.name
			info.level = tostring(role_vo.level)
			PlatformBinder:JsonCall("call_agent_on_report_exit", cjson.encode(info), "", function(arg)
				--通知SDK退出
				agent_helper:Exit(function(result)
					if "true" == result then
						AdapterToLua:endGame()
					else
						local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
						self:OpenAlertDialog(format, function (result) if "positive" == result then AdapterToLua:endGame() end end)
					end
				end)
			end)
		end
	else
		AdapterToLua:endGame()
	end	
end

-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end

